@@ -8,7 +8,7 @@ getResponse.default <- function(object,...){
 }
 
 getResponse.lm <- function(object,...) {
-	responsevar <- as.character(formula(object$model))[2]
+	responsevar <- as.character(formula(object))[2]
 	ans <- model.frame(object$model)[,responsevar]
 	return(ans)
 }
